Tree disassembler — converts AssembledTree back to ordered segments.
Walks the MIG schema tree in order. For each MIG node that has corresponding data in the assembled tree, emits segments in MIG order.
Structs
- Disassembled
Segment - Output segment from disassembly (owned data, ready for rendering).
- Disassembler
- MIG-guided disassembler — walks the MIG tree to emit segments in correct order.
- Missing
Entry Segment - A group instance that carries content but not the segment that opens the
group in the MIG (e.g. an SG10 with a
CAVbut noCCI).